<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;

class PessoaRepository {
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    public function getPessoa($nrorg, $nrvinculom, $dtmescompetenc ) {
        $sql = <<<SQL
    SELECT
        PH.*,
        VM.NRVINCULOM,
        VM.DTADMISSAOVINC,
        VM.DTRESCISAOVINC,
        PM.DTESOCIAL,
        PM.NRPARCNEGOCIO,
        PAIS.NMPAIS,
        EST.NMESTADO,
        MUN.NMMUNICIPIO,
        ESTRG.NMESTADO AS NMUFRGPESSOA,
        ESTCTPS.NMESTADO AS NMUFCTPSPES,
        ESTCONS.NMESTADO AS NMUFCONSREG,
        EC.NMESTACIVIL,
        CF.DSCONDFISPES,
        RP.NMRACAPESSOA,
        GI.NMGRAUINSTR,
        CM.NMCATMILITARPE,
        NAC.DSNACIONALIDADE,
        CR.NMCONSELHOREG,
        CE.DSCLASSESTRANG 
    FROM
        GPE_PESSOA PM 
    JOIN
        GPE_PESSOAH PH 
            ON PH.NRPESSOA = PM.NRPESSOA 
            AND PH.NRORG = PM.NRORG 
            AND PH.DTMESCOMPETENC = (
                SELECT
                    MAX(H1.DTMESCOMPETENC) 
            FROM
                GPE_PESSOAH H1 
            WHERE
                H1.NRPESSOA = PH.NRPESSOA 
                AND H1.NRORG = PH.NRORG 
                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC 
        ) 
    LEFT JOIN
        PAIS 
            ON PAIS.CDPAIS = PH.CDPAIS 
    LEFT JOIN
        ESTADO EST 
            ON EST.SGESTADO = PH.SGESTADO 
            AND EST.CDPAIS = PAIS.CDPAIS 
    LEFT JOIN
        MUNICIPIO MUN 
            ON MUN.CDMUNICIPIO = PH.CDMUNICIPIO 
            AND MUN.SGESTADO = EST.SGESTADO 
            AND MUN.CDPAIS = EST.CDPAIS 
    LEFT JOIN
        ESTADO ESTRG 
            ON ESTRG.SGESTADO = PH.SGUFRGPESSOA 
            AND ESTRG.CDPAIS = '0055' 
    LEFT JOIN
        ESTADO ESTCTPS 
            ON ESTCTPS.SGESTADO = PH.SGUFCTPSPES 
            AND ESTCTPS.CDPAIS = '0055' 
    LEFT JOIN
        ESTADO ESTCONS 
            ON ESTCONS.SGESTADO = PH.SGUFCONSREG 
            AND ESTCONS.CDPAIS = '0055' 
    LEFT JOIN
        ESTADOCIVIL EC 
            ON EC.CDESTACIVIL = PH.CDESTACIVIL 
    LEFT JOIN
        GPE_CONDFISPES CF 
            ON CF.NRCONDFISPES = PH.NRCONDFISPES 
    LEFT JOIN
        GPE_RACAPESSOA RP 
            ON RP.NRRACAPESSOA = PH.NRRACAPESSOA 
    LEFT JOIN
        GPE_GRAUINSTR GI 
            ON GI.NRGRAUINSTR = PH.NRGRAUINSTR 
    LEFT JOIN
        GPE_CATMILITARPE CM 
            ON CM.NRCATMILITARPE = PH.NRCATMILITARPE 
    LEFT JOIN
        GPE_NACIONALIDADE NAC 
            ON NAC.NRNACIONALIDADE = PH.NRNACIONALID 
    LEFT JOIN
        GPE_CONSELHOREG CR 
            ON CR.NRCONSELHOREG = PH.NRCONSELHOREG 
    LEFT JOIN
        GPE_CLASSESTRANG CE 
            ON CE.NRCLASSESTRANG = PH.NRCLASSESTRANG 
    JOIN
        GPE_VINCULOM VM 
            ON VM.NRPESSOA = PM.NRPESSOA 
            AND VM.NRORG = PM.NRORG 
        AND VM.NRVINCULOM = :P_NRVINCULOM
    WHERE
        PM.NRORG = :P_NRORG
SQL;

        $params = array(
            'P_NRORG'           => $nrorg,
            'P_NRVINCULOM'      => $nrvinculom,
            'P_DTMESCOMPETENC'  => $dtmescompetenc
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $periodo = $std->fetch();

        return $periodo;
    }

    /**
     * @return array|bool
     */
    public function getPessoaByCpf(
        int    $nrOrg,
        string $cpf
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GPE_PESSOAH PH
                JOIN GPE_PESSOA PM ON
                    PM.NRORG = PH.NRORG AND
                    PM.NRPESSOA = PH.NRPESSOA
            WHERE
                PH.NRORG = :P_NRORG AND
                PH.NRCPFPESSOA = :P_CPF
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_CPF' => $cpf,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $pessoa = $std->fetch();

        return $pessoa;
    }

    /**
     * @return array|bool
     */
    public function getPessoaByPis(
        int    $nrOrg,
        string $pis
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GPE_PESSOAH
            WHERE
                NRORG = :P_NRORG AND
                NRPISPASEPPES = :P_PIS
SQL;

        $params = [
            'P_NRORG' => $nrOrg,
            'P_PIS' => $pis,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $pessoa = $std->fetch();

        return $pessoa;
    }

    public function setPessoa(
        array $params
    ) {
        $sql = <<<SQL
            INSERT INTO GPE_PESSOA (
                NRPESSOA,       NRORG,          NRPARCNEGOCIO,
                DTINCLUSAO,     DTULTATU,       NRORGINCLUSAO,
                CDOPERINCLUSAO, NRORGULTATU,    CDOPERULTATU,
                DTESOCIAL
            )
            VALUES (
                :NRPESSOA,       :NRORG,          :NRPARCNEGOCIO,
                :DTINCLUSAO,     :DTULTATU,       :NRORGINCLUSAO,
                :CDOPERINCLUSAO, :NRORGULTATU,    :CDOPERULTATU,
                :DTESOCIAL
            )
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function setPessoaH(
        array $params
    ) {
        $sql = <<<SQL
            INSERT INTO GPE_PESSOAH (
                NRPESSOAH,          NRPESSOA,           NRORG,
                DTMESCOMPETENC,     NMPESSOA,           DSPRONOMETRAT,
                DSAPELIDOPESS,      DSPRINOMEPESS,      DSULTNOMEPESS,
                DSNOMEMEIOPESS,     CDESTACIVIL,        NRCONDFISPES,
                NRANOCHEGAPAIS,     NRDOCUESTRANG,      IDPOSVISTOPERM,
                DTPERMAVISTO,       IDPESNATURALIZA,    DTNATURALIZAPES,
                NRCPFPESSOA,        NRREGCTPSPES,       NRCTPSPESSOA,
                NRSERIECTPSPES,     SGUFCTPSPES,        DTCTPSPESSOA,
                NRPISPASEPPES,      DTINSCPISPASEP,     NRINSCINSSPES,
                NRINSCISSPES,       NRCERTNASCPES,      NRCERTCASAPES,
                DTCASAPESSOA,       IDISENTITUELEI,     NRTITUELEIPES,
                NRSECAELEIPES,      NRZONAELEIPES,      NRCARTHABPES,
                DTHABCARTPES,       DTVALHABCARTPES,    DSCATEGHABCART,
                NRCATMILITARPE,     NRCERTRESEPES,      DSCATEGCERTRESE,
                DTCERTRESEPES,      CDEXCERTRESEPES,    NRCONSELHOREG,
                NRINSCRCONSREG,     DTEXCONSREG,        SGUFCONSREG,
                DTINCLUSAO,         DTULTATU,           NRORGINCLUSAO,
                CDOPERINCLUSAO,     NRORGULTATU,        CDOPERULTATU,
                NRRACAPESSOA,       IDGRUPSANGUPES,     IDFATORRHPES,
                CDPAIS,             SGESTADO,           CDMUNICIPIO,
                DTNASCPESSOA,       IDSEXOPESSOA,       CDTPBAIXAPAG,
                NRRGPESSOA,         CDEXRGPESSOA,       SGUFRGPESSOA,
                DSLOCALEXRGPES,     DTEXRGPESSOA,       NRNACIONALID,
                NRGRAUINSTR,        DSCOMPLCERTNASC,    NRLIVROCERTNASC,
                NRFOLHACERTNASC,    DSCAMINHOFOTO,      IDPOSSUIFILHO,
                NRIDADEFILHO,       DTINIVIGENCIA,      DTFIMVIGENCIA,
                NRLIVROCERTCASA,    NRFOLHACERTCASA,    SGUFHABCARPES,
                DSEXPDOCESTR,       NRCLASSESTRANG,     NRCERTOBITO,
                DTCHEGADAPAIS,      NRSUSPESSOA,        NRNITPESSOA,
                DTADMISSAOPRE,      CDRECIBOADMPRE,     IDCOTAPCD
            )
            VALUES (
                :NRPESSOAH,         :NRPESSOA,          :NRORG,
                :DTMESCOMPETENC,    :NMPESSOA,          :DSPRONOMETRAT,
                :DSAPELIDOPESS,     :DSPRINOMEPESS,     :DSULTNOMEPESS,
                :DSNOMEMEIOPESS,    :CDESTACIVIL,       :NRCONDFISPES,
                :NRANOCHEGAPAIS,    :NRDOCUESTRANG,     :IDPOSVISTOPERM,
                :DTPERMAVISTO,      :IDPESNATURALIZA,   :DTNATURALIZAPES,
                :NRCPFPESSOA,       :NRREGCTPSPES,      :NRCTPSPESSOA,
                :NRSERIECTPSPES,    :SGUFCTPSPES,       :DTCTPSPESSOA,
                :NRPISPASEPPES,     :DTINSCPISPASEP,    :NRINSCINSSPES,
                :NRINSCISSPES,      :NRCERTNASCPES,     :NRCERTCASAPES,
                :DTCASAPESSOA,      :IDISENTITUELEI,    :NRTITUELEIPES,
                :NRSECAELEIPES,     :NRZONAELEIPES,     :NRCARTHABPES,
                :DTHABCARTPES,      :DTVALHABCARTPES,   :DSCATEGHABCART,
                :NRCATMILITARPE,    :NRCERTRESEPES,     :DSCATEGCERTRESE,
                :DTCERTRESEPES,     :CDEXCERTRESEPES,   :NRCONSELHOREG,
                :NRINSCRCONSREG,    :DTEXCONSREG,       :SGUFCONSREG,
                :DTINCLUSAO,        :DTULTATU,          :NRORGINCLUSAO,
                :CDOPERINCLUSAO,    :NRORGULTATU,       :CDOPERULTATU,
                :NRRACAPESSOA,      :IDGRUPSANGUPES,    :IDFATORRHPES,
                :CDPAIS,            :SGESTADO,          :CDMUNICIPIO,
                :DTNASCPESSOA,      :IDSEXOPESSOA,      :CDTPBAIXAPAG,
                :NRRGPESSOA,        :CDEXRGPESSOA,      :SGUFRGPESSOA,
                :DSLOCALEXRGPES,    :DTEXRGPESSOA,      :NRNACIONALID,
                :NRGRAUINSTR,       :DSCOMPLCERTNASC,   :NRLIVROCERTNASC,
                :NRFOLHACERTNASC,   :DSCAMINHOFOTO,     :IDPOSSUIFILHO,
                :NRIDADEFILHO,      :DTINIVIGENCIA,     :DTFIMVIGENCIA,
                :NRLIVROCERTCASA,   :NRFOLHACERTCASA,   :SGUFHABCARPES,
                :DSEXPDOCESTR,      :NRCLASSESTRANG,    :NRCERTOBITO,
                :DTCHEGADAPAIS,     :NRSUSPESSOA,       :NRNITPESSOA,
                :DTADMISSAOPRE,     :CDRECIBOADMPRE,    :IDCOTAPCD
            )
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getEstadoCivilByNm(
        string $nmEstadoCivil
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                ESTADOCIVIL
            WHERE
                INSTR(UPPER(NMESTACIVIL), UPPER(:P_NMESTADOCIVIL)) <> 0
SQL;

        $params = [
            'P_NMESTADOCIVIL' => $nmEstadoCivil,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        return $result;
    }

    public function getRacaByNm(
        string $nmRaca
    ) {
        $sql = <<<SQL
            SELECT
                *
            FROM
                GPE_RACAPESSOA
            WHERE
                INSTR(UPPER(NMRACAPESSOA), UPPER(:P_NMRACA)) <> 0 OR
                INSTR(UPPER(:P_NMRACA), UPPER(NMRACAPESSOA)) <> 0
SQL;

        $params = [
            'P_NMRACA' => $nmRaca,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        return $result;
    }
}